unit FMX.HTTP.Request;

{
  author: ZuBy
  email: rzaripov1990@gmail.com

  https://github.com/rzaripov1990
}

interface

type
  TmyAPI = record
  private
    class function msgErr: string; static;
    class function msgErrInternet: string; static;
    class function CheckInet: boolean; static;
  public
    class function IsOK(const aData: string): boolean; static;
    class function ErrorText(const aData: string): string; static;
    class function Request(const aURL: string): string; static;
  end;

implementation

uses
  System.Classes, System.SysUtils,
  System.Net.HTTPClient, System.Net.HTTPClientComponent;

const
  SIGNATURE = '[TmyAPI]';
  SIGNATURE_LEN = Length(SIGNATURE);

class function TmyAPI.CheckInet: boolean;
var
  aResp: IHTTPResponse;
begin
  Result := false;
  with TNetHTTPClient.Create(nil) do
  begin
    try
      try
        aResp := Head('http://google.com');
        Result := aResp.StatusCode < 400;
      except
        Result := false;
      end;
    finally
      Free;
    end;
  end;
end;

class function TmyAPI.Request(const aURL: string): string;
var
  aReturn: IHTTPResponse;
  aResp: TStringStream;
begin
  if not TmyAPI.CheckInet then
  begin
    Result := TmyAPI.msgErrInternet;
    exit;
  end;
  Result := TmyAPI.msgErr;
  aResp := TStringStream.Create('', TEncoding.UTF8);
  with TNetHTTPClient.Create(nil) do
  begin
    try
      try
        aReturn := Get(aURL, aResp);
        Result := aResp.DataString;
      except
        Result := TmyAPI.msgErr;
      end;
    finally
      Free;
      aResp.Free;
    end;
  end;
end;

class function TmyAPI.ErrorText(const aData: string): string;
begin
  Result := aData.Substring(SIGNATURE_LEN);
end;

class function TmyAPI.IsOK(const aData: string): boolean;
begin
  Result := not aData.StartsWith(SIGNATURE);
end;

class function TmyAPI.msgErr: string;
begin
  Result := SIGNATURE + 'Error';
end;

class function TmyAPI.msgErrInternet: string;
begin
  Result := SIGNATURE + 'No Internet';
end;

end.
